instrumenttools.BaritoneVoice
=============================

.. abjad-lineage:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice

.. autoclass:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BaritoneVoice.BaritoneVoice.BaritoneVoice.__repr__
   :noindex:
